<?php
namespace Elementor;

class Dina_Woo_Products_Grid extends Widget_Base {

	public function get_name() {
		return 'dina-woo-products-grid';
	}
	
	public function get_title() {
		return __( 'Dina Woo Products Grid', 'dina-kala' );
	}
	
	public function get_icon() {
		return 'fal fa-th';
	}
	
	public function get_categories() {
		return [ 'dina-kala' ];
	}
	
	protected function _register_controls() {
	global $di_data;
	require get_template_directory() . '/includes/widgets/fa.php';
		$prod_cata = array();
		$categories = get_terms("product_cat");
		if ( !empty( $categories ) && !is_wp_error( $categories ) ){
		foreach ( $categories as $category ) {
		$prod_cata[ $category->term_id ] = $category->name;
		}
		}

		$prod_taga = array();
		$tags = get_terms("product_tag");
		if ( !empty( $tags ) && !is_wp_error( $tags ) ){
		foreach ( $tags as $tag ) {
		$prod_taga[ $tag->term_id ] = $tag->name;
		}
		}

		if($di_data['product_brand']){
			$prod_brand = array();
			$brands = get_terms("brand");
			if ( !empty( $brands ) && !is_wp_error( $brands ) ){
			foreach ( $brands as $brand ) {
			$prod_brand[ $brand->term_id ] = $brand->name;
			}
			}
		}
		

		$this->start_controls_section(
			'section_title',
			[
				'label' => __( 'Dina Woo Products Grid', 'dina-kala' ),
			]
		);
		
		$this->add_control(
			'title',
			[
				'label' => __( 'Title', 'dina-kala' ),
				'label_block' => true,
				'type' => Controls_Manager::TEXT,
				'placeholder' => __( 'Enter your title', 'dina-kala' ),
			]
		);

		$this->add_control(
			'prod_sort',
			[
				'label' => __( 'Product sorting', 'dina-kala' ),
				'type' => Controls_Manager::SELECT,
				'default' => 'latest',
				'options' => [
					'latest'  => __( 'Latest products', 'dina-kala' ),
					'random' => __( 'Random products', 'dina-kala' ),
					'viewed' => __( 'Most viewed products', 'dina-kala' ),
					'saled' => __( 'Best selling products', 'dina-kala' ),
					'discounted' => __( 'Discounted products', 'dina-kala' ),
					'special' => __( 'Special products', 'dina-kala' ),
				],
			]
		);

		if($di_data['product_brand']){
		$this->add_control(
			'prod_filter',
			[
				'label' => __( 'Product filtering', 'dina-kala' ),
				'type' => Controls_Manager::SELECT,
				'default' => 'category',
				'options' => [
					'category'  => __( 'Products category', 'dina-kala' ),
					'tag' => __( 'Products tag', 'dina-kala' ),
					'brand' => __( 'Products brand', 'dina-kala' ),
				],
			]
		);
		} else {
			$this->add_control(
				'prod_filter',
				[
					'label' => __( 'Product filtering', 'dina-kala' ),
					'type' => Controls_Manager::SELECT,
					'default' => 'category',
					'options' => [
						'category'  => __( 'Products category', 'dina-kala' ),
						'tag' => __( 'Products tag', 'dina-kala' ),
					],
				]
			);
		}
		$this->add_control(
			'product_cat',
			[
				'label' => __( 'Product category', 'dina-kala' ),
				'type' => Controls_Manager::SELECT2,
				'options' => $prod_cata,
			]
		);

		$this->add_control(
			'product_tag',
			[
				'label' => __( 'Product tag', 'dina-kala' ),
				'type' => Controls_Manager::SELECT2,
				'options' => $prod_taga,
			]
		);

		if($di_data['product_brand']){
			$this->add_control(
				'product_brand',
				[
					'label' => __( 'Product brand', 'dina-kala' ),
					'type' => Controls_Manager::SELECT2,
					'options' => $prod_brand,
				]
			);
		}

		$this->add_control(
			'out_prod',
			[
				'label' => __( 'Show in stock products', 'dina-kala' ),
				'type' => Controls_Manager::SWITCHER,
				'label_on' => __( 'On', 'dina-kala' ),
				'label_off' => __( 'Off', 'dina-kala' ),
				'return_value' => 'yes',
				'default' => 'no',
			]
		);

		$this->add_control(
			'product_icon',
			[
				'label' => __( 'Icon', 'dina-kala' ),
				'type' => Controls_Manager::SELECT2,
				'options' => $icons_font_awesome,
			]
		);
		
		$this->add_control(
			'custom_icon',
			[
				'label' => __( 'Or custom icon (Suitable size: 32px by 32px)', 'dina-kala' ),
				'type' => Controls_Manager::MEDIA,
			]
		);

		$this->add_control(
			'white_title',
			[
				'label' => __( 'White title (Suitable for background mode)', 'dina-kala' ),
				'type' => Controls_Manager::SWITCHER,
				'label_on' => __( 'On', 'dina-kala' ),
				'label_off' => __( 'Off', 'dina-kala' ),
				'return_value' => 'yes',
				'default' => 'no',
			]
		);

		$this->add_control(
			'white_box',
			[
				'label' => __( 'White box style', 'dina-kala' ),
				'type' => Controls_Manager::SWITCHER,
				'label_on' => __( 'On', 'dina-kala' ),
				'label_off' => __( 'Off', 'dina-kala' ),
				'return_value' => 'yes',
				'default' => 'no',
			]
		);

		$this->add_control(
			'ptotalcount',
			[
				'label' => __( 'Product total count', 'dina-kala' ),
				'type' => Controls_Manager::NUMBER,
				'min' => 1,
				'max' => 20,
				'step' => 1,
				'default' => 10,
			]
		);

		$this->add_control(
			'pcount',
			[
				'label' => __( 'Product columns count', 'dina-kala' ),
				'type' => Controls_Manager::NUMBER,
				'min' => 2,
				'max' => 5,
				'step' => 1,
				'default' => 5,
			]
		);

		$this->add_control(
			'view_all',
			[
				'label' => __( 'Display view all button (If category or tag selected)', 'dina-kala' ),
				'type' => Controls_Manager::SWITCHER,
				'label_on' => __( 'On', 'dina-kala' ),
				'label_off' => __( 'Off', 'dina-kala' ),
				'return_value' => 'yes',
				'default' => 'no',
			]
		);
		
		$this->end_controls_section();
	}
	
	protected function render() {
		$settings = $this->get_settings_for_display();
		global $di_data; ?>
        <div class="product-block-grid<?php if ( 'yes' === $settings['white_title'] ) { echo ' white-title'; } ?><?php if ( 'yes' === $settings['white_box'] ) { echo ' white-box'; } ?>">
		<?php
		$prod_sort = $settings['prod_sort'];
		$prod_filter = $settings['prod_filter'];
		$product_cat = $settings['product_cat'];
		$product_tag = $settings['product_tag'];
		if($di_data['product_brand']){
			$product_brand = $settings['product_brand'];
		} else {
			$product_brand = '';
		}
		$view_all_link = '';
			if($prod_sort != 'special') {
			switch ($prod_sort) {
				case 'latest':
					$args = array(
					'posts_per_page' => $settings['ptotalcount'],
					'post_type' => 'product',
					'post_status' => 'publish',
					'order' => 'DESC'  );
					break;
				case 'saled':
					$args = array(
					'posts_per_page' => $settings['ptotalcount'],
					'post_type' => 'product',
					'post_status' => 'publish',
					'meta_key' => 'total_sales',
                    'orderby' => 'meta_value_num',
                    'order' => 'DESC'  );
					break;
				case 'discounted':
					$args = array(
						'posts_per_page'    => $settings['ptotalcount'],
						'post_status'       => 'publish',
						'order' => 'DESC',
						'post_type'         => 'product',
						'post__in'          => array_merge( array( 0 ), wc_get_product_ids_on_sale() )
					);
					break;
				case 'viewed':
					$args = array(
					'posts_per_page' => $settings['ptotalcount'],
					'post_type' => 'product',
					'post_status' => 'publish',
					'meta_key' => 'post_views_count',
                    'orderby' => 'meta_value_num',
                    'order' => 'DESC'  );
					break;
				case 'random':
					$args = array(
					'posts_per_page' => $settings['ptotalcount'],
					'post_type' => 'product',
					'post_status' => 'publish',
					'orderby'        => 'rand'  );
					break;
				default:
				$args = array(
					'posts_per_page' => $settings['ptotalcount'],
					'post_type' => 'product',
					'post_status' => 'publish',
					'order' => 'DESC'  );
				}
				$view_all_link = '';
				if ( $prod_filter ) {
					if ( $prod_filter == 'category' && $product_cat != '') {
						$args['tax_query'] = array(
							array(
							'taxonomy' => 'product_cat',
							'field' => 'term_id',
							'terms' => $product_cat
							)
						);
						$view_all_link = get_term_link((int)$product_cat,'product_cat');
					} elseif ( $prod_filter == 'tag' && $product_tag != '') {
						$args['tax_query'] = array(
							array(
							'taxonomy' => 'product_tag',
							'field' => 'term_id',
							'terms' => $product_tag
							)
						);
						$view_all_link = get_term_link((int)$product_tag,'product_tag');
					} elseif ( $prod_filter == 'brand' && $product_brand != '') {
						$args['tax_query'] = array(
							array(
							'taxonomy' => 'brand',
							'field' => 'term_id',
							'terms' => $product_brand
							)
						);
						$view_all_link = get_term_link((int)$product_brand,'brand');
					}
				}
			}
			elseif ($prod_sort == 'special') {
				$args = array(
					'posts_per_page' => $settings['ptotalcount'],
					'post_type' => 'product',
					'post_status' => 'publish',
					'order' => 'DESC'  );
					if ( !empty($prod_filter) && ($product_cat != '' || $product_tag != '' || $product_brand != '') ) {
					if ( $prod_filter == 'category' && $product_cat != '') {
						$args['tax_query'] = array(
						'relation' => 'AND',
						array(
							'taxonomy' => 'product_visibility',
							'field'    => 'name',
							'terms'    => 'featured',
						),
						array(
						'taxonomy' => 'product_cat',
						'field' => 'term_id',
						'terms' => $product_cat
						)
					);
					} elseif ( $prod_filter == 'tag' && $product_tag != '') { 
						$args['tax_query'] = array(
						'relation' => 'AND',
						array(
							'taxonomy' => 'product_visibility',
							'field'    => 'name',
							'terms'    => 'featured',
						),
						array(
						'taxonomy' => 'product_tag',
							'field' => 'term_id',
							'terms' => $product_tag
						)
					);
					} elseif ( $prod_filter == 'brand' && $product_brand != '') { 
						$args['tax_query'] = array(
						'relation' => 'AND',
						array(
							'taxonomy' => 'product_visibility',
							'field'    => 'name',
							'terms'    => 'featured',
						),
						array(
						'taxonomy' => 'brand',
							'field' => 'term_id',
							'terms' => $product_brand
						)
					);
					}
				} else {
					$args['tax_query'] = array(
						array(
							'taxonomy' => 'product_visibility',
							'field'    => 'name',
							'terms'    => 'featured',
						),
					);
				}
			}

			if('yes' === $settings['out_prod']){
				$args['meta_query'] = array(
						'relation' => 'AND',
						array(
							'key' => '_stock_status',
							'value' => 'instock'
						)
					);
			}

			$productsquery = new \WP_Query( $args );
		?>
		
		<?php if ( $productsquery->have_posts() ) { ?>
		<?php if(!empty($settings['title'])) { ?>
		<div class="block-title">
			<h2>
				<?php if(!empty($settings['custom_icon']['url'])){ ?>
					<img src="<?php echo $settings['custom_icon']['url']; ?>" alt="<?php echo $settings['title']; ?>" class="cust-icon">
				<?php } else { ?>
					<i class="fal fa-<?php echo $settings['product_icon']; ?>" aria-hidden="true"></i>
				<?php } ?>
				<?php echo $settings['title']; ?>
			</h2>
		</div>
		<?php } ?>
		<div class="row">
		<?php 
			if($settings['pcount'] == 2){
				$pclasses = 'col-6';
			}
			elseif($settings['pcount'] == 3){
				$pclasses = 'col-md-4 col-6';
			}
			elseif($settings['pcount'] == 4){
				$pclasses = 'col-md-3 col-6';
			}
			elseif($settings['pcount'] == 5){
				$pclasses = 'col-20 col-md-3 col-6';
			}
		?>
		<?php while ( $productsquery->have_posts() ) : $productsquery->the_post(); ?>
			<?php global $product;
				$in_stock = $product->is_in_stock();
			?>
			<div class="<?php echo $pclasses; ?> mini-product-con type-product"> 
				<div class="<?php echo dina_mini_product_classes($product->get_id()); ?>">
					<a href="<?php the_permalink(); ?>" title="<?php the_title_attribute(); ?>" class="product-link">
						<?php pr_img() ?>
						<?php if($in_stock && $product->is_on_sale()) { ?>
						<?php echo dina_dis_price(get_the_ID()); ?>
						<?php } ?>
						<span class="product-title">
							<?php the_title(); ?>
						</span>
						<span class="product-price">
						<?php if($in_stock) { ?>
							<span class="price-con">
							<?php echo $product->get_price_html(); ?>
							</span>
						<?php } else { ?>
							<span class="price-con">
							<?php _e( 'Out of stock', 'dina-kala' ); ?>
							</span>
						<?php } ?>
						</span>
					</a>
					<?php dina_add_to_cart($product); ?>
				</div>
			</div>
		<?php endwhile; ?>
		</div>
		<?php if ( 'yes' === $settings['view_all'] && $view_all_link != '' ) { ?>
			<a href="<?php echo $view_all_link; ?>" class="btn btn-outline-dina pgview-all">
				<?php _e( 'View All Products' , 'dina-kala' ); ?>
				<i class="fal fa-chevron-left" aria-hidden="true"></i>
			</a>
		<?php } ?>
		<?php 
		} else {		
		echo '<div class="col-12 not-msg">'.__( 'No product with the desired conditions was found.', 'dina-kala' ).'</div>';}
		
		wp_reset_postdata();
		?>
        </div>
        <?php

	}

}